local_moving_FT_zigzag: Calculate the moving Fourier transform ordinates

View source: R/dynamicWhittle_miscellanea_zigzag.R

local_moving_FT_zigzagR Documentation

Calculate the moving Fourier transform ordinates

Description

Calculate the moving Fourier transform ordinates

Usage

local_moving_FT_zigzag(x, m, thinning_factor)

Arguments

x

A numeric vector containing time series.

m

A positive integer indicating the size of window.

thinning_factor

Selected from "1, 2, 3".

Value

A list containing the moving Fourier transform and corresponding time grid.

References

Tang et al. (2025) Bayesian nonparametric spectral analysis of locally stationary processes JASA <doi:10.1080/01621459.2025.2594191>

Examples

set.seed(1); x <- rnorm(1500)
local_moving_FT_zigzag(x, 50, 1)

beyondWhittle documentation built on April 15, 2026, 9:06 a.m.