realValuedPsd: Store imaginary parts above and real parts below the diagonal

View source: R/RcppExports.R

realValuedPsdR Documentation

Store imaginary parts above and real parts below the diagonal

Description

Store imaginary parts above and real parts below the diagonal

Usage

realValuedPsd(f_)

beyondWhittle documentation built on April 15, 2026, 9:06 a.m.